@@ -1,13 +1,13 @@
 package Game::Theory::TwoPersonMatrix;
-BEGIN {
-  $Game::Theory::TwoPersonMatrix::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Analyze a 2 person matrix game
 
 use strict;
 use warnings;
 
+our $VERSION = '0.2006';
+
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
 use Array::Transpose;
@@ -15,8 +15,6 @@ use List::MoreUtils qw( all zip );
 use List::Util qw( max min );
 use List::Util::WeightedChoice qw( choose_weighted );
 
-our $VERSION = '0.2005';
-
 
 
 sub new {
@@ -195,24 +193,14 @@ sub oddments
     my $D = $self->{payoff}[1][1];
 
     my ( $x, $y );
-    $x = $D - $C;
-    $y = $A - $B;
-    if ( $x < 0 || $y < 0 )
-    {
-        $x = $C - $D;
-        $y = $B - $A;
-    }
+    $x = abs( $D - $C );
+    $y = abs( $A - $B );
     my $i = $x / ( $x + $y );
     my $j = $y / ( $x + $y );
     $player = [ $i, $j ];
 
-    $x = $D - $B;
-    $y = $A - $C;
-    if ( $x < 0 || $y < 0 )
-    {
-        $x = $B - $D;
-        $y = $C - $A;
-    }
+    $x = abs( $D - $B );
+    $y = abs( $A - $C );
     $i = $x / ( $x + $y );
     $j = $y / ( $x + $y );
     $opponent = [ $i, $j ];
@@ -504,25 +492,27 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2005
+version 0.2006
 
 =head1 SYNOPSIS
 
  use Game::Theory::TwoPersonMatrix;
- $g = Game::Theory::TwoPersonMatrix->new(
+
+ my $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => 0.2, 2 => 0.3, 3 => 0.5 },
     2 => { 1 => 0.1, 2 => 0.7, 3 => 0.2 },
     payoff => [ [-5, 4, 6],
                 [ 3,-2, 2],
                 [ 2,-3, 1] ]
- };
+ );
  $g->row_reduce();
  $g->col_reduce();
- $p = $g->saddlepoint();
- $o = $g->oddments();
- $e = $g->expected_payoff();
- $c = $g->counter_strategy($player);
- $u = $g->play();
+ my $player = 1;
+ my $p = $g->saddlepoint();
+ my $o = $g->oddments();
+ my $e = $g->expected_payoff();
+ my $c = $g->counter_strategy($player);
+ my $u = $g->play();
 
  $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => 0.1, 2 => 0.2, 3 => 0.7 },
@@ -537,9 +527,9 @@ version 0.2005
                  [3,4,4,1],
                  [5,6,8,2] ],
  );
- $t = $g->mm_tally();
- $m = $g->pareto_optimal();
- $n = $g->nash();
+ my $t = $g->mm_tally();
+ my $m = $g->pareto_optimal();
+ my $n = $g->nash();
  $e = $g->expected_payoff();
  $c = $g->counter_strategy($player);
  $u = $g->play();
